changeset 1084:a29670271217

(Fcall_interactively): For `K', use last_nonmenu_event. Make `e' alias for `K'.
author Richard M. Stallman <rms@gnu.org>
date Sat, 05 Sep 1992 00:10:28 +0000
parents cbbbe0a96ecc
children 91a456e52db1
files src/callint.c
diffstat 1 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/callint.c	Sat Sep 05 00:09:33 1992 +0000
+++ b/src/callint.c	Sat Sep 05 00:10:28 1992 +0000
@@ -66,10 +66,11 @@
 C -- Command name: symbol with interactive function definition.\n\
 d -- Value of point as number.  Does not do I/O.\n\
 D -- Directory name.\n\
+e -- Mouse click that invoked this command (value of `last-nonmenu-event').\n\
 f -- Existing file name.\n\
 F -- Possibly nonexistent file name.\n\
 k -- Key sequence (string).\n\
-K -- Mouse click that invoked this command - last-command-char.\n\
+K -- Mouse click that invoked this command (value of `last-nonmenu-event').\n\
 m -- Value of mark as number.  Does not do I/O.\n\
 n -- Number read using minibuffer.\n\
 N -- Prefix arg converted to number, or if none, do like code `n'.\n\
@@ -390,7 +391,8 @@
 	  break;
 
 	case 'K':		/* Mouse click.  */
-	  args[i] = last_command_char;
+	case 'e':		/* New, better name.  */
+	  args[i] = last_nonmenu_event;
 	  if (NILP (Fmouse_click_p (args[i])))
 	    error ("%s must be bound to a mouse click.",
 		   (XTYPE (function) == Lisp_Symbol